==> haskell-hls-tactics-plugin-1.8.0.0-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-tactics-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-tactics-plugin
version:              1.8.0.0
visibility:           public
id:                   hls-tactics-plugin-1.8.0.0-8Kh7OUtooMCH1mOwkRXvg3
key:                  hls-tactics-plugin-1.8.0.0-8Kh7OUtooMCH1mOwkRXvg3
license:              Apache-2.0
copyright:            Sandy Maguire, Reed Mullanix
maintainer:           sandy@sandymaguire.me
author:               Sandy Maguire, Reed Mullanix
homepage:             https://haskellwingman.dev
synopsis:             Wingman plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  035143c9cc12ff2a632f766a171450c4
exposed:              True
exposed-modules:
    Ide.Plugin.Tactic Refinery.Future Wingman.AbstractLSP
    Wingman.AbstractLSP.TacticActions Wingman.AbstractLSP.Types
    Wingman.Auto Wingman.CaseSplit Wingman.CodeGen
    Wingman.CodeGen.Utils Wingman.Context Wingman.Debug
    Wingman.EmptyCase Wingman.GHC Wingman.Judgements
    Wingman.Judgements.SYB Wingman.Judgements.Theta
    Wingman.KnownStrategies Wingman.KnownStrategies.QuickCheck
    Wingman.LanguageServer Wingman.LanguageServer.Metaprogram
    Wingman.LanguageServer.TacticProviders Wingman.Machinery
    Wingman.Metaprogramming.Lexer Wingman.Metaprogramming.Parser
    Wingman.Metaprogramming.Parser.Documentation
    Wingman.Metaprogramming.ProofState Wingman.Naming Wingman.Plugin
    Wingman.Range Wingman.Simplify Wingman.StaticPlugin Wingman.Tactics
    Wingman.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hls-tactics-plugin-1.8.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hls-tactics-plugin-1.8.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-tactics-plugin
hs-libraries:         HShls-tactics-plugin-1.8.0.0-8Kh7OUtooMCH1mOwkRXvg3
depends:
    aeson-2.1.2.1-ACNZHhH4U2e67aZXZDgTOb base-4.15.1.0
    containers-0.6.4.1 deepseq-1.4.5.0 directory-1.3.6.2
    extra-1.7.14-1peTzRJ4sdJJmIV6KfSmoB filepath-1.4.2.1
    fingertree-0.1.5.0-2myi5JkKmsPIIwoIfJ4rPO
    generic-lens-2.2.2.0-5InGvPRqQS55vmTCAOSR2j ghc-9.0.2
    ghc-boot-th-9.0.2 ghc-exactprint-0.6.4-Jo7yR2qBwA6LxXK3wWvCPB
    ghc-source-gen-0.4.3.0-F6BXv1bGMne5f6b67HW7BO
    ghcide-1.9.0.0-3KflzuXi2s6AXw125fR0jm
    hls-graph-1.9.0.0-3KObtqpOGMdBpM7LIenDea
    hls-plugin-api-1.6.0.0-ItndApsjDSA9T7dufzQXiZ
    hls-refactor-plugin-1.1.0.0-2vs1TeDOva8Lfo7Aok4ld
    hyphenation-0.8.2-1keNBk5xPVd56wYRcb0zBu
    lens-5.2.3-A4jq1zRTTDpJs4RZBLF7I7
    lsp-1.6.0.0-LPBD4p5QyQJ8TEnBD5gyoN
    megaparsec-9.3.1-4O8gvkmCTKu5idiIpE5hUy mtl-2.2.2
    parser-combinators-1.3.0-FL5bcA6sX4a2ejs4tDtkjB
    prettyprinter-1.7.1-3BN5DqkhAKiEdjSMkhtuTG
    refinery-0.4.0.0-JVSUtvLjkI77RZm5xhdZxU
    retrie-1.1.0.0-LBYslwSNUz4GF3nNMkPCvN
    syb-0.7.2.3-F4C6wO1lPr57dhtwlEni6j text-1.2.5.0
    transformers-0.5.6.2 unagi-chan-0.4.1.4-Gwp1arhwEnsB2pDlpaIjxm
    unordered-containers-0.2.19.1-J4eg8YowQRtEC3N7B7zfuy

haddock-interfaces:
    /usr/share/doc/haskell-hls-tactics-plugin/html/hls-tactics-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-tactics-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-tactics-plugin-1.8.0.0-100-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-tactics-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-tactics-plugin
version:              1.8.0.0
visibility:           public
id:                   hls-tactics-plugin-1.8.0.0-GCR0u1Uy8KQ9KOqvinvIz8
key:                  hls-tactics-plugin-1.8.0.0-GCR0u1Uy8KQ9KOqvinvIz8
license:              Apache-2.0
copyright:            Sandy Maguire, Reed Mullanix
maintainer:           sandy@sandymaguire.me
author:               Sandy Maguire, Reed Mullanix
homepage:             https://haskellwingman.dev
synopsis:             Wingman plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  c2454d06951937456433a01c943a3475
exposed:              True
exposed-modules:
    Ide.Plugin.Tactic Refinery.Future Wingman.AbstractLSP
    Wingman.AbstractLSP.TacticActions Wingman.AbstractLSP.Types
    Wingman.Auto Wingman.CaseSplit Wingman.CodeGen
    Wingman.CodeGen.Utils Wingman.Context Wingman.Debug
    Wingman.EmptyCase Wingman.GHC Wingman.Judgements
    Wingman.Judgements.SYB Wingman.Judgements.Theta
    Wingman.KnownStrategies Wingman.KnownStrategies.QuickCheck
    Wingman.LanguageServer Wingman.LanguageServer.Metaprogram
    Wingman.LanguageServer.TacticProviders Wingman.Machinery
    Wingman.Metaprogramming.Lexer Wingman.Metaprogramming.Parser
    Wingman.Metaprogramming.Parser.Documentation
    Wingman.Metaprogramming.ProofState Wingman.Naming Wingman.Plugin
    Wingman.Range Wingman.Simplify Wingman.StaticPlugin Wingman.Tactics
    Wingman.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hls-tactics-plugin-1.8.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hls-tactics-plugin-1.8.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-tactics-plugin
hs-libraries:         HShls-tactics-plugin-1.8.0.0-GCR0u1Uy8KQ9KOqvinvIz8
depends:
    aeson-2.1.2.1-5LFbz27UeRc2IE39j8tZaA base-4.15.1.0
    containers-0.6.4.1 deepseq-1.4.5.0 directory-1.3.6.2
    extra-1.7.14-E0Vd3mK76yeChjxyVVp3Nf filepath-1.4.2.1
    fingertree-0.1.5.0-F3W7XVVWAqK5RzCXUB3LxT
    generic-lens-2.2.2.0-FppnxLlGer15aq7N7Mgs92 ghc-9.0.2
    ghc-boot-th-9.0.2 ghc-exactprint-0.6.4-7K0RLCxuKA74OkSbKHu53J
    ghc-source-gen-0.4.3.0-GbM6IcUpfu37s8Qk2B1tEN
    ghcide-1.9.1.0-5tdMTHNfhOF6yHM8w9b0Yh
    hls-graph-1.9.0.0-INz4OAQhuNuAtxu2E4bsNd
    hls-plugin-api-1.6.0.0-7ErxYe6odJi7RLnCXR8rgW
    hls-refactor-plugin-1.1.0.0-9EiQ4R4eMrD3uO1BxLOG6p
    hyphenation-0.8.2-BWv5uQzRoD4DPLbOQN3xHK
    lens-5.2.3-C6rN0cGlCsvJR5IO9scZ1s lsp-1.6.0.0-2iWbi0wH1g8cUKC0kYQAl
    megaparsec-9.5.0-89dsU4g24QaJMgENlWCp7T mtl-2.2.2
    parser-combinators-1.3.0-FL5bcA6sX4a2ejs4tDtkjB
    prettyprinter-1.7.1-7kytBxFAg8kIPJJstNahcA
    refinery-0.4.0.0-Hkv6kzQw28zE2muRF0IaSF
    retrie-1.1.0.0-59wTRiFCnaNIddJpnyCMD0
    syb-0.7.2.3-JqzSMUO0Mg375L5LIm8jI0 text-1.2.5.0
    transformers-0.5.6.2 unagi-chan-0.4.1.4-H7ihq7B2WW5llUN0WAz81
    unordered-containers-0.2.19.1-UA49xtzCSp2PJ1xuqchgw

haddock-interfaces:
    /usr/share/doc/haskell-hls-tactics-plugin/html/hls-tactics-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-tactics-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
